@@ -1,7 +1,7 @@
 """Implements the Mercurial VCS dialect."""
 import os
 
-from uvc.commands import UVCError, DialectCommand
+from uvc.commands import UVCError, DialectCommand, StatusOutput
 
 class HgError(UVCError):
     """A Mercurial-dialect specific error."""
@@ -31,10 +31,27 @@ class commit(HgCommand):
     reads_remote = False
     writes_remote = False
     
+    def command_parts(self):
+        parts = super(commit, self).command_parts()
+        if self.generic.user:
+            parts.insert(1, "-u")
+            parts.insert(2, self.generic.user)
+        return parts
+    
 class diff(HgCommand):
     reads_remote = False
     writes_remote = False
     
+class remove(HgCommand):
+    reads_remote = False
+    writes_remote = False
+    
+    def command_parts(self):
+        parts = super(remove, self).command_parts()
+        # uvc's remove command implies "force"
+        parts.insert(1, "-f")
+        return parts
+
 class add(HgCommand):
     reads_remote = False
     writes_remote = False
@@ -63,6 +80,13 @@ class resolved(HgCommand):
         if not self.targets:
             parts.append("-a")
         return parts
+        
+class status(HgCommand):
+    reads_remote = False
+    writes_remote = False
+    
+    def process_output(self, returncode, stdout):
+        return StatusOutput(returncode, stdout)
     
 class HgDialect(object):
     def convert(self, command_object):
