@@ -1,9 +1,12 @@
 import os
+from cStringIO import StringIO
 
 from uvc.path import path
 from uvc import commands, hg, main
 from uvc.tests.util import test_context
 
+StatusOutput = commands.StatusOutput
+
 dialect = hg.HgDialect()
 
 topdir = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..", 
@@ -40,11 +43,14 @@ def test_convert_unknown_command():
         pass
 
 def test_commit_command():
+    test_context.user = "Zaphod Beeblebrox <zaphod@onecooldude.us>"
     generic_commit = commands.commit(test_context, ["-m", "test message", "foo", "bar"])
     result = dialect.convert(generic_commit)
     assert not result.reads_remote
     assert not result.writes_remote
-    assert str(result) == "commit -m test message foo bar"
+    command_parts = result.command_parts()
+    assert command_parts == ["commit", "-u", "Zaphod Beeblebrox <zaphod@onecooldude.us>",
+                            "-m", "test message", "foo", "bar"]
     
 def test_diff_command():
     generic_diff = commands.diff(context, [])
@@ -116,4 +122,48 @@ def test_resolved_command_no_targets():
     assert not resolved.reads_remote
     assert not resolved.writes_remote
     assert resolved.get_command_line() == ["hg", "resolve", "-m", "-a"]
+    
+def test_remove_command_no_targets():
+    myfile = path(topdir) / "myfile"
+    myfile.write_bytes("test data")
+    try:
+        generic_remove = commands.remove(context, ["myfile"])
+        remove = hg.remove(generic_remove)
+    finally:
+        myfile.unlink()
+        
+    assert not remove.reads_remote
+    assert not remove.writes_remote
+    assert remove.get_command_line() == ["hg", "remove", "-f", "myfile"]
+    
+def test_status_command():
+    generic_status = commands.status(context, [])
+    status = hg.status(generic_status)
+    assert not status.writes_remote
+    assert not status.reads_remote
+    
+    assert status.get_command_line() == ["hg", "status"]
+    
+    status_output = """M modified/file
+A new/file
+R removed/file
+C clean/file
+! missing/file
+? unknown/file
+I ignored/file
+"""
+    
+    output = status.process_output(0, StringIO(status_output))
+    the_list = output.as_list()
+    print the_list
+    assert the_list == [
+[StatusOutput.MODIFIED, "modified/file"],
+[StatusOutput.ADDED, "new/file"],
+[StatusOutput.REMOVED, "removed/file"],
+[StatusOutput.CLEAN, "clean/file"],
+[StatusOutput.MISSING, "missing/file"],
+[StatusOutput.UNKNOWN, "unknown/file"],
+[StatusOutput.IGNORED, "ignored/file"]
+]
+    assert str(output) == status_output
     
\ No newline at end of file
